
#ifndef __SNGTC_SERVER_H__
#define __SNGTC_SERVER_H__

// common configuration options & declarations (always include first)
#include "config.h"

// C language includes
#include <stdio.h>
#include <stdlib.h> // atoi, exit
#include <string.h>


#if PLATFORM(Windows)
#define snprintf _snprintf
#endif

// application includes
#include "Server.h" /* server_xxx functions */

#include <sng_tc/sng_tc.h>


typedef struct system_eth_cfg{
	int 			init;
	char 			name[100];
	sngtc_eth_mac_t mac;
	sngtc_ip_t 		ip;
	sngtc_ip_t 		mask;
	uint32_t 		flags;
	uint8_t 		set_if_up;
}system_eth_cfg_t;



extern sngtc_init_cfg_t g_init;

int sngtc_parse_xml_config_file(char *file);
int sngtc_detect_eth_dev(void);
int sngtc_find_mac_by_eth(uint8_t *ethdev, system_eth_cfg_t **eth_cfg);
int log_printf(int level, char* fmt, ...);

#if 0
#define SNGTC_PRINT(level,a,...) log_printf(level,a,##__VA_ARGS__)
#define SNGTC_DEBUG(a,...) 		SNGTC_PRINT(SNGTC_LOGLEVEL_DEBUG,a,##__VA_ARGS__)
#define SNGTC_WARN(a,...) 		SNGTC_PRINT(SNGTC_LOGLEVEL_WARN,a,##__VA_ARGS__)
#define SNGTC_INFO(a,...) 		SNGTC_PRINT(SNGTC_LOGLEVEL_L_INFO,a,##__VA_ARGS__)
#define SNGTC_STATS(a,...) 		SNGTC_PRINT(SNGTC_LOGLEVEL_STATS,a,##__VA_ARGS__)
#define SNGTC_ERROR(a,...)		SNGTC_PRINT(SNGTC_LOGLEVEL_ERROR,a,##__VA_ARGS__)
#define SNGTC_CRIT(a,...) 		SNGTC_PRINT(SNGTC_LOGLEVEL_CRIT,a,##__VA_ARGS__)
#define SNGTC_RES(a,...) 		SNGTC_PRINT(SNGTC_LOGLEVEL_L_RES,a,##__VA_ARGS__)
#define SNGTC_TEST(a,...)

#define SNGTC_L_LOGLEVEL_DECODE(level) \
		((level==SNGTC_LOGLEVEL_DEBUG) ? "SNGTC_DEBUG" : \
		(level==SNGTC_LOGLEVEL_WARN) ? "SNGTC_WARN" : \
		(level==SNGTC_LOGLEVEL_INFO) ? "SNGTC_INFO" : \
		(level==SNGTC_LOGLEVEL_L_INFO) ? "SNGTC_INFO" : \
		(level==SNGTC_LOGLEVEL_L_RES) ? "SNGTC_RESLT" : \
		(level==SNGTC_LOGLEVEL_STATS) ? "SNGTC_STATS" : \
		(level==SNGTC_LOGLEVEL_ERROR) ? "SNGTC_ERROR" : \
		(level==SNGTC_LOGLEVEL_CRIT) ? "SNGTC_CRIT" : "Unknown")        
#endif

#define TS2_LOGLEVEL_DECODE(level) \
		((level==LOG_LEVEL_FATAL) ? "LOG_LEVEL_FATAL" : \
		 (level==LOG_LEVEL_ERROR) ? "LOG_LEVEL_ERROR" : \
		 (level==LOG_LEVEL_WARN) ? "LOG_LEVEL_WARN" : \
		 (level==LOG_LEVEL_INFO) ? "LOG_LEVEL_INFO" : \
		 (level==LOG_LEVEL_DEBUG) ? "LOG_LEVEL_DEBUG" : \
		 (level==LOG_LEVEL_TRACE) ? "LOG_LEVEL_TRACE" :  "Unknown")

#endif

